/*
 * Copyright (c) 2009 by syntevo GmbH. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of syntevo GmbH nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.syntevo.openapi.smartsvn.settings;

import java.io.*;

import com.syntevo.openapi.smartsvn.settings.gui.*;

/**
 * Services related to {@link Settings}.
 */
public interface SettingsServices {

	/**
	 * Creates a file with the specified name in SmartSVN's settings directory.
	 *
	 * @param name the name of the settings file
	 */
	File getSettingsFile(String name);

	/**
	 * Creates a file with the specified name relative to the SmartSVN default settings directory (which usually is located at &lt;install-dir&gt;/default).
	 * @param name the name/relative path of the file
	 */
	File getDefaultSettingsFile(String name);

	/**
	 * Returns the global settings (Preferences), see {@link Settings}
	 */
	SettingsProvider getGlobalSettingsProvider();

	/**
	 * Adds the specified {@link ISettingsPageFactory} factory which
	 * pages to the global settings (Preferences).
	 */
	void addGlobalSettingsPageFactory(ISettingsPageFactory factory);
}
