package com.syntevo.plugin.jira.commit;

import java.awt.*;
import javax.swing.*;

import com.syntevo.openapi.gui.*;
import com.syntevo.openapi.gui.dialog.*;
import com.syntevo.q.gui.layout.*;

/**
 * @author syntevo GmbH
 */
final class JiraCredentialsDialog extends AbstractOkCancelDialog {

	// Fields =================================================================

	private final String username;
	private final String password;
	private final boolean storePassword;
	private final GuiSpacings spacings;

	private JTextField usernameField;
	private JPasswordField passwordField;
	private JCheckBox storePasswordCheckBox;

	// Setup ==================================================================

	public JiraCredentialsDialog(String username, String password, boolean storePassword, GuiSpacings spacings) {
		this.username = username;
		this.password = password;
		this.storePassword = storePassword;
		this.spacings = spacings;

		getOkAction().setName("Login");
	}

	// Implemented ============================================================

	public String getTitle() {
		return "JIRA - Login";
	}

	public JComponent createComponent(Container parent) {
		final JComponent panel = new JPanel();
		parent.add(panel);

		final JLabel usernameLabel = JiraUiUtils.createLabel("Username", 'U');
		usernameField = JiraUiUtils.createTextField(username, 10, usernameLabel);

		final JLabel passwordLabel = JiraUiUtils.createLabel("Password", 'P');
		passwordField = JiraUiUtils.createPasswordField(password != null, passwordLabel);

		storePasswordCheckBox = new JCheckBox("Store password (will be stored in plain text!)");
		storePasswordCheckBox.setMnemonic('S');
		storePasswordCheckBox.setSelected(storePassword);

		final TableGridLayoutFactory layout = new TableGridLayoutFactory(panel);
		layout.addColumnNoStretch();
		layout.addColumnNoStretch(spacings.getXRelated());
		layout.addColumnStretchOnResize();
		layout.addRowNoStretch();
		layout.addRowNoStretch(spacings.getYUnrelated());
		layout.addRowNoStretch();
		layout.addRowNoStretch(spacings.getYUnrelated());
		layout.addRowNoStretch();
		layout.addComponent(usernameLabel, 0, 0);
		layout.addComponent(usernameField, 0, 2);
		layout.addComponent(passwordLabel, 2, 0);
		layout.addComponent(passwordField, 2, 2);
		layout.addComponent(storePasswordCheckBox, 4, 0, 1, 3, true, true, true, false);
		return panel;
	}

	public void validate() throws DialogValidationFailedException {
		if (getUsername().length() == 0) {
			throw new DialogValidationFailedException("Please enter a username.", usernameField);
		}

		if (getPassword().length() == 0) {
			throw new DialogValidationFailedException("Please enter a password.", passwordField);
		}
	}

	@Override
	public void dialogShowing() {
		super.dialogShowing();
		final JComponent componentToFocus = getUsername().length() == 0 ? usernameField : passwordField;
		componentToFocus.requestFocus();
	}

	// Accessing ==============================================================

	public String getUsername() {
		return usernameField.getText();
	}

	public String getPassword() {
		return JiraUiUtils.getPassword(passwordField, password);
	}

	public boolean isStorePassword() {
		return storePasswordCheckBox.isSelected();
	}
}